@@ -1,4 +1,10 @@
-from tqdm import tqdm
+"""
+Convenience wrappers for progress bars to allow interface with pyQT.
+
+(c) Oscar Branson : https://github.com/oscarbranson
+"""
+
+from tqdm.autonotebook import tqdm
 
 class progressbar(tqdm):
     def __init__(self):
